pub enum AuthPolicy {
Authenticated,
Unauthenticated,
}Variants
Authenticated
Authorized to access the requested path with operation as long
as the given Route does not require Root level privilege.
Unauthenticated
Anyone without a token.