pub enum Response {
Raw(Value),
Auth(AuthResponse),
Lease(LeaseResponse),
}Expand description
Response from the backend
Variants
Raw(Value)
Raw response. The data will be returned as is to the client.
Auth(AuthResponse)
Authentication response. The client will receive a token for the given alias.
Lease(LeaseResponse)
Register a lease for the payload. Useful for returning dynamic secrets that can be revoked and renewed.
Implementations